pub struct StaticLatencyModel { /* private fields */ }Expand description
Static latency model with fixed latency values.
Models the latency for different order operations including base network latency and specific operation latencies for insert, update, and delete operations.
The base latency is automatically added to each operation latency, matching
Python’s behavior. For example, if base_latency_nanos = 100ms and
insert_latency_nanos = 200ms, the effective insert latency will be 300ms.
Implementations
Sourceimpl StaticLatencyModel
impl StaticLatencyModel
Sourcepub fn new(
base_latency_nanos: UnixNanos,
insert_latency_nanos: UnixNanos,
update_latency_nanos: UnixNanos,
delete_latency_nanos: UnixNanos,
) -> Self
pub fn new( base_latency_nanos: UnixNanos, insert_latency_nanos: UnixNanos, update_latency_nanos: UnixNanos, delete_latency_nanos: UnixNanos, ) -> Self
Creates a new StaticLatencyModel instance.
The base latency is added to each operation latency to get the effective latency.
Arguments
base_latency_nanos- Base network latency added to all operationsinsert_latency_nanos- Additional latency for order insertionupdate_latency_nanos- Additional latency for order updatesdelete_latency_nanos- Additional latency for order cancellation